#GetOutputWithXPath.py
import spss, spssaux, tempfile, os.path

#Generate output from the Frequencies procedure for the variables inccat and 
#income from demo.sav, and route the output to the XML workspace. In this example,
#the output consists of pivot tables and bar charts.
spss.Submit("""GET FILE='/examples/data/demo.sav'.
OMS
  /SELECT CHARTS TABLES
  /IF COMMANDS=['Frequencies']
  /DESTINATION FORMAT=OXML IMAGES=YES 
   CHARTFORMAT=IMAGE IMAGEROOT='myimages' IMAGEFORMAT=JPG XMLWORKSPACE='demo'.

FREQUENCIES VARIABLES=inccat income
  /STATISTICS=MEDIAN
  /BARCHART FREQ
  /ORDER=ANALYSIS.

OMSEND.
""")

#Get the median value of the variable income from the XML workspace.
xpath="//category[@text='Median']//category[@varName='income']/cell/@number"
median=spss.EvaluateXPath('demo','/outputTree',xpath)[0]

#Get the bar chart for the variable inccat and save it to the user's temporary directory.
xpath="//chartTitle[@text='Income category in thousands']/chart/@imageFile"
imagename=spss.EvaluateXPath('demo','/outputTree',xpath)[0]
image = spss.GetImage('demo',imagename)
f = file(os.path.join(tempfile.gettempdir(),imagename),'wb')
f.truncate(image[1])
f.write(image[0])
f.close()

#Generate an html file that displays the retrieved bar chart along with an annotation 
#for the median income. 
f = file(os.path.join(tempfile.gettempdir(),'demo.html'),'w')
f.write('<html>')
f.write('<head>')
f.write('<title>Sample web page</title>')
f.write('</head>')
f.write('<body>')
f.write('<h2>Sample web page content</h2>')
f.write('<img src="file:///' + os.path.join(tempfile.gettempdir(),imagename) +'"/>')
f.write('<p><strong>***The median income is ' + median + ' thousand</p>')
f.close()